pub enum RoutineStrategy {
Unit(BlueprintStrategy<UnitRoutine>),
Plane(BlueprintStrategy<PlaneRoutine>),
Cube(BlueprintStrategy<CubeRoutine>),
}Variants
Unit(BlueprintStrategy<UnitRoutine>)
A unit is responsible to reduce a full vector.
Plane(BlueprintStrategy<PlaneRoutine>)
A plane is responsible to reduce a full vector.
Cube(BlueprintStrategy<CubeRoutine>)
A cube is responsible to reduce a full vector.